@@ -1,8 +1,7 @@
 #! /usr/bin/python
 # -*- coding: utf-8 -*-
 
-__project__ = 'z2n-periodogram'
-__version__ = '2.0.3'
+__version__ = '2.0.5'
 __license__ = 'MIT'
 __author__ = 'Yohan Alexander'
 __copyright__ = 'Copyright (C) 2020, Z2n Software, by Yohan Alexander.'
@@ -13,12 +12,3 @@ __status__ = 'Development'
 __credits__ = 'Yohan Alexander'
 __docs__ = 'https://z2n-periodogram.readthedocs.io'
 __url__ = 'https://github.com/yohanalexander/z2n-periodogram'
-
-import click
-import matplotlib
-try:
-    matplotlib.use('tkagg')
-except ImportError:
-    click.secho("Failed to use interactive backend.", fg='red')
-    click.secho(
-        "Check Tkinter dependency: sudo apt-get install python3-tk""", fg='yellow')
